@@ -33,18 +33,20 @@
 #' @param Bfrac fraction of SSBMSY that is the target
 #' @param maxF maximum apical fishing mortality
 #' @param ploty logical: should a plot be produced
+#' @param plusgroup Integer. Default = 0 = no plus-group. Use 1 to include a plus-group 
 #' @author T. Carruthers with modifications by A. Hordyk
 #' @keywords internal
 getBlow<-function(x, N, Asize, SSBMSY, SSBpR, MPA, SSB0, nareas, retA,MGThorizon,Find,
                   Perr,M_ageArray,hs,Mat_age,Wt_age,R0a,V,nyears,maxage,mov,Spat_targ,SRrel,
-                  aR,bR,Bfrac=0.5, maxF, ploty=F){
+                  aR,bR,Bfrac=0.5, maxF, ploty=F, plusgroup=0){
   
   opt <-optimize(Blow_opt,log(c(0.0075,15)),N=N[x,,1,], Asize_c =Asize[x,], SSBMSYc=SSBMSY[x],
                  SSBpRc=SSBpR[x,], MPA=MPA, SSB0c=SSB0[x], nareas, retAc=retA[x,,],
                  MGThorizonc=MGThorizon[x], Fc=Find[x,],Perrc=Perr[x,], Mc=M_ageArray[x,,], 
                  hc=hs[x], Mac=Mat_age[x,,], Wac=Wt_age[x,,], R0c=R0a[x,], Vc=V[x,,], 
                  nyears=nyears, maxage=maxage, movc=mov[x,,,,], Spat_targc=Spat_targ[x], 
-                 SRrelc=SRrel[x], aRc=aR[x,], bRc=bR[x,], Bfrac, maxF, mode=1)
+                 SRrelc=SRrel[x], aRc=aR[x,], bRc=bR[x,], Bfrac, maxF, mode=1,
+                 plusgroup=plusgroup)
   
   if(ploty){
     Blow_opt(opt$minimum,N=N[x,,1,], Asize_c =Asize[x,], SSBMSYc=SSBMSY[x],
@@ -52,7 +54,8 @@ getBlow<-function(x, N, Asize, SSBMSY, SSBpR, MPA, SSB0, nareas, retA,MGThorizon
              MGThorizonc=MGThorizon[x], Fc=Find[x,],Perrc=Perr[x,], Mc=M_ageArray[x,,], 
              hc=hs[x], Mac=Mat_age[x,,], Wac=Wt_age[x,,], R0c=R0a[x,], Vc=V[x,,], 
              nyears=nyears, maxage=maxage, movc=mov[x,,,,], Spat_targc=Spat_targ[x], 
-             SRrelc=SRrel[x], aRc=aR[x,], bRc=bR[x,], Bfrac, maxF, mode=3)
+             SRrelc=SRrel[x], aRc=aR[x,], bRc=bR[x,], Bfrac, maxF, mode=3,
+             plusgroup=plusgroup)
   }
   
   Blow_opt(opt$minimum,N=N[x,,1,], Asize_c =Asize[x,], SSBMSYc=SSBMSY[x],
@@ -60,7 +63,8 @@ getBlow<-function(x, N, Asize, SSBMSY, SSBpR, MPA, SSB0, nareas, retA,MGThorizon
            MGThorizonc=MGThorizon[x], Fc=Find[x,],Perrc=Perr[x,], Mc=M_ageArray[x,,], 
            hc=hs[x], Mac=Mat_age[x,,], Wac=Wt_age[x,,], R0c=R0a[x,], Vc=V[x,,], 
            nyears=nyears, maxage=maxage, movc=mov[x,,,,], Spat_targc=Spat_targ[x], 
-           SRrelc=SRrel[x], aRc=aR[x,], bRc=bR[x,], Bfrac, maxF, mode=2)
+           SRrelc=SRrel[x], aRc=aR[x,], bRc=bR[x,], Bfrac, maxF, mode=2,
+           plusgroup=plusgroup)
   
   
 }
@@ -99,11 +103,12 @@ getBlow<-function(x, N, Asize, SSBMSY, SSBpR, MPA, SSB0, nareas, retA,MGThorizon
 #' @param Bfrac fraction of SSBMSY that is the target
 #' @param maxF maximum apical fishing mortality
 #' @param mode 1: find Blow 2:report blow  3:plot results
+#' @param plusgroup Integer. Default = 0 = no plus-group. Use 1 to include a plus-group 
 #' @author T. Carruthers with modifications by A. Hordyk
 #' @keywords internal 
 Blow_opt<-function(lnq, N, Asize_c, SSBMSYc,SSBpRc, MPA, SSB0c, nareas, retAc,
                    MGThorizonc,Fc,Perrc,Mc,hc,Mac,Wac,R0c,Vc,nyears,maxage,movc,Spat_targc,
-                   SRrelc,aRc,bRc,Bfrac,maxF, mode=1){
+                   SRrelc,aRc,bRc,Bfrac,maxF, mode=1, plusgroup=0){
   
   pyears <- nyears + MGThorizonc
 
@@ -126,7 +131,8 @@ Blow_opt<-function(lnq, N, Asize_c, SSBMSYc,SSBpRc, MPA, SSB0c, nareas, retAc,
                       MatAge, WtAge, Vuln, Retc, Prec, split.along.dim(movcx,4), 
                       SRrelc, Effind, Spat_targc, hc,
                       R0c=R0c, SSBpRc=SSBpRc, aRc=aRc, bRc=bRc, Qc=exp(lnq), Fapic=0,
-                      maxF=maxF, MPA=MPA, control=1, SSB0c=SSB0c)
+                      maxF=maxF, MPA=MPA, control=1, SSB0c=SSB0c,
+                      plusgroup = plusgroup)
 
   SSBstore <- apply(simpop[[4]],2, sum)
   SBiomass <- SSBstore[pyears]
